:py:mod:`piel.models.physical.units`
====================================

.. py:module:: piel.models.physical.units


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.models.physical.units.convert_awg_to_m2



.. py:function:: convert_awg_to_m2(awg: int) -> float

   Converts an AWG value to meters squared.

   Reference: https://en.wikipedia.org/wiki/American_wire_gauge

   :param awg: AWG value.
   :type awg: ing

   :returns: Cross sectional area in meters squared.
   :rtype: float
